/**
 * OW2 Util
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: WebservicesCommonClassMetadata.java 4493 2009-02-02 09:25:06Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ws.impl;

import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.impl.CommonClassMetadata;
import org.ow2.util.ee.metadata.ws.api.IWebservicesCommonClassMetadata;
import org.ow2.util.ee.metadata.ws.api.struct.IWebServiceMarker;

/**
 * WS common class metadata.
 * @author Guillaume Sauthier
 * @param <C> class type
 * @param <M> method type
 * @param <F> field type
 */
public class WebservicesCommonClassMetadata<
    C extends IWebservicesCommonClassMetadata<C, M, F>,
    M extends ICommonMethodMetadata<C, M, F>,
    F extends ICommonFieldMetadata<C, M, F>>
        extends CommonClassMetadata<C, M, F> implements IWebservicesCommonClassMetadata<C, M, F> {

    /**
     * Set if there is a @WebService or @WebServiceProvider annotation on the class.
     */
    private IWebServiceMarker serviceMarker;

    /**
     * @return IJwsWebService object representing javax.jws.WebService annotation.
     */
    public IWebServiceMarker getWebServiceMarker() {
        return serviceMarker;
    }

    /**
     * Set IJwsWebService object.
     *
     * @param ws object representing javax.jws.WebService annotation.
     */
    public void setWebServiceMarker(final IWebServiceMarker ws) {
        this.serviceMarker = ws;
    }

}