/**
 * OW2 Util
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: WebservicesClassMetadataConfigurator.java 4500 2009-02-02 12:52:24Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ws.impl.configurator;

import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.impl.configurator.CommonClassMetadataConfigurator;
import org.ow2.util.ee.metadata.ws.api.IWebservicesCommonClassMetadata;
import org.ow2.util.ee.metadata.ws.impl.configurator.visitor.clazz.JavaxJwsWebServiceVisitor;
import org.ow2.util.ee.metadata.ws.impl.configurator.visitor.clazz.JavaxXmlWsWebServiceProviderVisitor;
import org.ow2.util.scan.api.configurator.metadata.specific.ISpecificArchiveConfigurator;

import java.util.List;

/**
 * WebservicesCommonClassMetadataConfigurator.
 * @author Guillaume Sauthier
 * @param <C> class type
 * @param <M> method type
 * @param <F> field type
 */
public abstract class WebservicesClassMetadataConfigurator<
    C extends IWebservicesCommonClassMetadata<C, M, F>,
    M extends ICommonMethodMetadata<C, M, F>,
    F extends ICommonFieldMetadata<C, M, F>>
        extends CommonClassMetadataConfigurator<C, M, F> {

    /**
     * Constructor.
     * @param classMetadata classMetadata
     * @param specificArchiveConfiguratorList specific archive configurator list
     */
    public WebservicesClassMetadataConfigurator(final C classMetadata,
            final List<? extends ISpecificArchiveConfigurator<C, M, F>> specificArchiveConfiguratorList) {
        super(classMetadata, specificArchiveConfiguratorList);
    }

    /**
     * register annotation visitor.
     */
    protected void registerAnnotationVisitor() {

        // Don't forget to register ancestor's visitors
        super.registerAnnotationVisitor();

        C classMetadata = getClassMetadata();


        // add @WebService
        getAnnotationVisitors().put(JavaxJwsWebServiceVisitor.TYPE,
                                    new JavaxJwsWebServiceVisitor<C>(classMetadata));

        // add @WebServiceProvider
        getAnnotationVisitors().put(JavaxXmlWsWebServiceProviderVisitor.TYPE,
                                    new JavaxXmlWsWebServiceProviderVisitor<C>(classMetadata));

    }

}
