/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JavaxJwsWebServiceVisitor.java 4502 2009-02-03 10:31:47Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ws.impl.configurator.visitor.clazz;

import org.ow2.util.ee.metadata.common.impl.configurator.visitor.AbsAnnotationVisitor;
import org.ow2.util.ee.metadata.ws.api.IWebservicesCommonClassMetadata;
import org.ow2.util.ee.metadata.ws.api.struct.IWebServiceMarker;
import org.ow2.util.ee.metadata.ws.impl.struct.WebServiceMarker;

/**
 * This class manages the handling of &#64;{@link javax.jws.WebService} annotation.
 * @author Guillaume Sauthier
 */
public class JavaxJwsWebServiceVisitor<T extends IWebservicesCommonClassMetadata> extends AbsAnnotationVisitor<T> {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/jws/WebService;";

    /**
     * The @WebService annotation representant.
     */
    private IWebServiceMarker serviceMarker;

    /**
     * Constructor.
     * @param annotationMetadata linked to a class or method metadata
     */
    public JavaxJwsWebServiceVisitor(final T annotationMetadata) {
        super(annotationMetadata);
        serviceMarker = new WebServiceMarker();
    }

    /**
     * Visits a primitive value of the annotation.
     *
     * @param name  the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *              {@link Boolean}, {@link Character}, {@link Short},
     *              {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *              {@link String} or {@link org.ow2.util.scan.api.IType}.
     */
    @Override
    public void visit(String name, Object value) {
        if ("name".equals(name)) {
            serviceMarker.setName(name);
        }
    }

    /**
     * Visits the end of the annotation.
     */
    public void visitEnd() {
        if (serviceMarker.getName() == null) {
            // Compute default name (simple name of the class)
            String name = getAnnotationMetadata().getJClass().getName().replace('/', '.');
            int index = name.lastIndexOf(".");
            serviceMarker.setName(name.substring(index + 1));
        }
        getAnnotationMetadata().setWebServiceMarker(serviceMarker);
    }

    /**
     * @return type of the annotation (its description).
     */
    public String getType() {
        return TYPE;
    }
}
