/**
 * OW2 Util
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JavaxXmlWsWebServiceProviderVisitor.java 4503 2009-02-03 13:05:14Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ws.impl.configurator.visitor.clazz;

import org.ow2.util.ee.metadata.common.impl.configurator.visitor.AbsAnnotationVisitor;
import org.ow2.util.ee.metadata.ws.api.interfaces.IWebService;
import org.ow2.util.ee.metadata.ws.api.struct.IWebServiceMarker;
import org.ow2.util.ee.metadata.ws.api.IWebservicesCommonClassMetadata;
import org.ow2.util.ee.metadata.ws.impl.struct.WebServiceMarker;

/**
 * This class manages the handling of &#64;{@link javax.xml.ws.WebServiceProvider} annotation.
 * @author Guillaume Sauthier
 */
public class JavaxXmlWsWebServiceProviderVisitor<T extends IWebservicesCommonClassMetadata> extends AbsAnnotationVisitor<T> {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/xml/ws/WebServiceProvider;";

    /**
     * The WS metadata representant.
     */
    private IWebServiceMarker marker;

    /**
     * Constructor.
     * @param annotationMetadata linked to a class or method metadata
     */
    public JavaxXmlWsWebServiceProviderVisitor(final T annotationMetadata) {
        super(annotationMetadata);
        marker = new WebServiceMarker();
        marker.setWebServiceProvider(true);

        // Compute default port component name (FQN of the class)
        String name = annotationMetadata.getJClass().getName().replace('/', '.');
        marker.setName(name);

    }

    /**
     * Visits the end of the annotation.
     */
    public void visitEnd() {
        getAnnotationMetadata().setWebServiceMarker(marker);
    }

    /**
     * @return type of the annotation (its description).
     */
    public String getType() {
        return TYPE;
    }
}