/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: WebServiceMarker.java 4689 2009-02-23 14:23:05Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ws.impl.struct;

import org.ow2.util.ee.metadata.ws.api.struct.IWebServiceMarker;
import org.ow2.util.ee.metadata.common.api.xml.struct.IHandlerChains;

import javax.xml.namespace.QName;

/**
 * This class allow to set informations on @WebSrevice and @WebServiceProvider
 * annotation.
 * @author Guillaume Sauthier
 */
public class WebServiceMarker implements IWebServiceMarker {

    /**
     * Denotes a Provider WS.
     */
    private boolean webServiceProvider = false;

    /**
     * Location of the WSDL document.
     */
    private String wsdlLocation;

    /**
     * Name of the wsdl:service.
     */
    private QName serviceName;

    /**
     * Name of the wsdl:port.
     */
    private QName portName;

    /**
     * Protocol binding URI.
     */
    private String protocolBinding;

    /**
     * Enable MTOM for this port ?
     */
    private boolean enableMtom;

    /**
     * The overrided value for SEI classname.
     */
    private String endpointInterface;

    /**
     * Name of this port-component.
     */
    private String name;

    /**
     * HandlerChains resolved from deployment descriptor.
     */
    private IHandlerChains handlerChains;

    /**
     * @return true if this marker denotes a class annotated with @WebServiceProvider
     *         instead of @WebService.
     */
    public boolean isWebServiceProvider() {
        return webServiceProvider;
    }

    /**
     * Set if this class is annotated with @WebService or @WebServiceprovider
     *
     * @param wsProvider true/false
     */
    public void setWebServiceProvider(boolean wsProvider) {
        this.webServiceProvider = wsProvider;
    }

    /**
     * @return the WSDL location (may be null).
     */
    public String getWsdlLocation() {
        return wsdlLocation;
    }

    /**
     * @param wsdlLocation the overrided WSDL location.
     */
    public void setWsdlLocation(String wsdlLocation) {
        this.wsdlLocation = wsdlLocation;
    }

    /**
     * @return the overrided wsdl:service name (may be null)
     */
    public QName getServiceName() {
        return serviceName;
    }

    /**
     * @param serviceName overriding value for wsdl:service name.
     */
    public void setServiceName(QName serviceName) {
        this.serviceName = serviceName;
    }

    /**
     * @return the overrided wsdl:port name (may be null)
     */
    public QName getPortName() {
        return portName;
    }

    /**
     * @param portName overriding value for wsdl:port name.
     */
    public void setPortName(QName portName) {
        this.portName = portName;
    }

    /**
     * @return the overriding value for the protocol binding URI (may be null)
     */
    public String getProtocolBinding() {
        return protocolBinding;
    }

    /**
     * @param protocolBinding new URI specifying the overriding value for binding URI.
     */
    public void setProtocolBinding(String protocolBinding) {
        this.protocolBinding = protocolBinding;
    }

    /**
     * @return true if MTOM is enabled (false by default)
     */
    public boolean isEnableMtom() {
        return enableMtom;
    }

    /**
     * @param enableMtom should MTOM be enabled on this port ?
     */
    public void setEnableMtom(boolean enableMtom) {
        this.enableMtom = enableMtom;
    }

    /**
     * @return the overrided value for Service Endpoint Interface (may be null).
     */
    public String getEndpointInterface() {
        return endpointInterface;
    }

    /**
     * @param endpointInterface the overriding value for SEI.
     */
    public void setEndpointInterface(String endpointInterface) {
        this.endpointInterface = endpointInterface;
    }

    /**
     * @return the name of this web service (only applicable when using @WebService)
     */
    public String getName() {
        return name;
    }

    /**
     * Set the name of this serviceweb.
     *
     * @param name name of this webservice.
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Set the HandlerChains resolved from deployment descriptor.
     *
     * @param handlerChains HandlerChains resolved from deployment descriptor.
     */
    public void setHandlerChains(IHandlerChains handlerChains) {
        this.handlerChains = handlerChains;
    }

    /**
     * @return the HandlerChains elements resolved from deployment descriptor.
     */
    public IHandlerChains getHandlerChains() {
        return this.handlerChains;
    }
}
