/**
 * OW2 Util
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: Webservices12DeploymentDesc.java 4493 2009-02-02 09:25:06Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ws.impl.xml.parsing;

import org.ow2.util.archive.api.ArchiveException;
import org.ow2.util.archive.api.IArchive;
import org.ow2.util.ee.metadata.ws.api.xml.struct.IWebservices;
import org.ow2.util.ee.metadata.common.impl.xml.parsing.ParsingException;

import java.net.URL;

/**
 * The Webservices12DeploymentDesc is responsible to load the
 * webservices.xml (version 1.2/JAX-Ws only).
 *
 * @author Guillaume Sauthier
 */
public class Webservices12DeploymentDesc {

    /**
     * Defines where to look up the webservices.xml file.
     */
    public static enum Type {
        EJBJAR, WEBAPP
    }

    /**
     * Utility class, no public constructor.
     */
    private Webservices12DeploymentDesc() {

    }

    /**
     * Gets Webservices for a given archive.
     * @param archive file/directory.
     * @throws org.ow2.util.ee.metadata.common.impl.xml.parsing.ParsingException if no xml is present.
     * @return Webservices 1.2 instance or null.
     */
    public static IWebservices getWebservices12(final IArchive archive, Type type) throws ParsingException {

        // Get XML entry
        URL webservicesXmlURL = null;

        // Compute entry name
        String entryName = null;
        switch (type) {
            case EJBJAR:
                entryName = "META-INF/webservices.xml";
                break;
            case WEBAPP:
                entryName = "WEB-INF/webservices.xml";
                break;
        }

        try {
            webservicesXmlURL = archive.getResource(entryName);
        } catch (ArchiveException e) {
            throw new ParsingException("Cannot get resource '" + entryName + "' on the archive '"
                    + archive.getName() + "'.");
        }

        IWebservices webservices12 = null;
        // Get webservices object (if url valid)
        if (webservicesXmlURL != null) {
            webservices12 = WebservicesDeploymentDescLoader.loadDeploymentDescriptor(webservicesXmlURL);
        }

        // Only return something if this is a JAX-WS descriptor
        if ((webservices12 != null) && ("1.2".equals(webservices12.getVersion()))) {
            return webservices12;
        }

        return null;
    }

}
