/**
 * OW2 Util
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: PortComponent.java 4689 2009-02-23 14:23:05Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ws.impl.xml.struct;

import org.ow2.util.ee.metadata.ws.api.xml.struct.IPortComponent;
import org.ow2.util.ee.metadata.ws.api.xml.struct.IServiceImplBean;
import org.ow2.util.ee.metadata.ws.api.xml.struct.IWebserviceDescription;
import org.ow2.util.ee.metadata.common.api.xml.struct.IHandlerChains;

import javax.xml.namespace.QName;

/**
 * The PortComponent is ...
 *
 * @author Guillaume Sauthier
 */
public class PortComponent implements IPortComponent {

    /**
     * XML element's name.
     */
    public static final String NAME = "port-component";

    /**
     * This port component's name.
     */
    private String name;

    /**
     * Name of the wsdl:service targeted by this port component (may be null)
     */
    private QName wsdlService;

    /**
     * Name of the wsdl:port targeted by this port component (may be null)
     */
    private QName wsdlPort;

    /**
     * Is MTOM enabled ?
     */
    private boolean mtomEnabled;

    /**
     * The overriding Binding URI (may be null).
     */
    private String protocolBinding;

    /**
     * The overriding SEI (only applicable is @WebService) (may be null).
     */
    private String serviceEndpointInterface;

    /**
     * The SIB.
     */
    private IServiceImplBean serviceImplBean;

    /**
     * The parent webservice-description.
     */
    private IWebserviceDescription parent;

    /**
     * Handler Chains element.
     */
    private IHandlerChains handlerChains;

    /**
     * Build a port component child of the given description element.
     * @param parent the description
     */
    public PortComponent(IWebserviceDescription parent) {
        this.parent = parent;
    }

    public void setName(String name) {
        this.name = name;
    }

    public void setWsdlService(QName wsdlService) {
        this.wsdlService = wsdlService;
    }

    public void setWsdlPort(QName wsdlPort) {
        this.wsdlPort = wsdlPort;
    }

    public void setMTOMEnabled(boolean mtomEnabled) {
        this.mtomEnabled = mtomEnabled;
    }

    public void setProtocolBinding(String protocolBinding) {
        this.protocolBinding = protocolBinding;
    }

    public void setServiceEndpointInterface(String serviceEndpointInterface) {
        this.serviceEndpointInterface = serviceEndpointInterface;
    }

    public void setServiceImplBean(IServiceImplBean serviceImplBean) {
        this.serviceImplBean = serviceImplBean;
    }

    public String getName() {
        return name;
    }

    public QName getWsdlService() {
        return wsdlService;
    }

    public QName getWsdlPort() {
        return wsdlPort;
    }

    public boolean isMTOMEnabled() {
        return mtomEnabled;
    }

    public String getProtocolBinding() {
        return protocolBinding;
    }

    public String getServiceEndpointInterface() {
        return serviceEndpointInterface;
    }

    public IServiceImplBean getServiceImplBean() {
        return serviceImplBean;
    }

    public IWebserviceDescription getParent() {
        return parent;
    }

    public void setHandlerChains(IHandlerChains handlerChains) {
        this.handlerChains = handlerChains;
    }

    /**
     * @return the <code>handler-chains</code> element.
     */
    public IHandlerChains getHandlerChains() {
        return this.handlerChains;
    }
}
