/**
 * OW2 Util
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: Webservices.java 4493 2009-02-02 09:25:06Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ws.impl.xml.struct;

import org.ow2.util.ee.metadata.ws.api.xml.struct.IWebservices;
import org.ow2.util.ee.metadata.ws.api.xml.struct.IWebserviceDescription;
import org.ow2.util.ee.metadata.ws.api.xml.struct.IPortComponent;
import org.ow2.util.ee.metadata.ws.api.xml.struct.IServiceImplBean;

import java.util.List;
import java.util.ArrayList;

/**
 * The Webservices is ...
 *
 * @author Guillaume Sauthier
 */
public class Webservices implements IWebservices {

    /**
     * Value of the @version attribute.
     */
    private String version;

    /**
     * List of descriptions declared in this file.
     */
    private List<IWebserviceDescription> webserviceDescriptions;

    /**
     * Default constructor.
     */
    public Webservices() {
        this.webserviceDescriptions = new ArrayList<IWebserviceDescription>();
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public void addWebserviceDescription(IWebserviceDescription webserviceDescription) {
        this.webserviceDescriptions.add(webserviceDescription);
    }

    public String getVersion() {
        return version;
    }

    public List<IWebserviceDescription> getWebserviceDescriptions() {
        return webserviceDescriptions;
    }

    public IPortComponent findPortComponent(String sibLink) {

        for (IWebserviceDescription description : webserviceDescriptions) {

            for (IPortComponent portComponent : description.getPortComponents()) {

                IServiceImplBean sib = portComponent.getServiceImplBean();

                if (sibLink.equals(sib.getServletLink()) || sibLink.equals(sib.getEjbLink())) {
                    return portComponent;
                }
            }
        }
        return null;
    }
}
